.. _capi-selection:

Function manipulating ``CHFL_SELECTION``
----------------------------------------

.. doxygentypedef:: CHFL_SELECTION

.. doxygenfunction:: chfl_selection

.. doxygenfunction:: chfl_selection_copy

.. doxygenfunction:: chfl_selection_size

.. doxygenfunction:: chfl_selection_string

.. doxygenfunction:: chfl_selection_evaluate

.. doxygenfunction:: chfl_selection_matches

.. doxygenfunction:: chfl_selection_free

.. doxygenstruct:: chfl_match
    :members:

.. doxygendefine:: CHFL_MAX_SELECTION_SIZE
